Pagination class

Inheritance

Constructors

Pagination({Key? key, required int numOfPages, required int selectedPage, required int pagesVisible, required ValueChanged<int> onPageChanged, TextStyle? activeTextStyle, ButtonStyle? activeBtnStyle, TextStyle? inactiveTextStyle, ButtonStyle? inactiveBtnStyle, Icon? previousIcon, Icon? nextIcon, double? spacing, bool showFirstLastButtons = false, Icon? firstPageIcon, Icon? lastPageIcon, bool isRounded = false, bool isCircular = false})
const

Properties

activeBtnStyle ButtonStyle?
final
activeTextStyle TextStyle?
final
firstPageIcon Icon?
final
hashCode int
The hash code for this object.
no setterinherited
inactiveBtnStyle ButtonStyle?
final
inactiveTextStyle TextStyle?
final
isCircular bool
final
isRounded bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lastPageIcon Icon?
final
nextIcon Icon?
final
numOfPages int
final
onPageChanged ValueChanged<int>
final
pagesVisible int
final
previousIcon Icon?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedPage int
final
showFirstLastButtons bool
final
spacing double?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Pagination>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited